@@ -1,23 +1,19 @@
 """Command line interface."""
 
-import contextlib
 import threading
 from pathlib import Path
-from typing import Optional
 
 import xdg
 from libcli import BaseCLI
 from loguru import logger
 
 import tf2mon
-import tf2mon.controls
 import tf2mon.layouts
+from tf2mon._logger import configure_logger
+from tf2mon._monitor import Monitor
 from tf2mon.conlog import Conlog
 from tf2mon.controls import Controls
 from tf2mon.database import Database
-from tf2mon.hacker import HackerManager
-from tf2mon.logger import configure_logger
-from tf2mon.monitor import Monitor
 from tf2mon.steamweb import SteamWebAPI
 
 
@@ -50,42 +46,13 @@ class CLI(BaseCLI):
         "player_name": "Bad Dad",
     }
 
-    # Create all controls.
-    controls = Controls("tf2mon.controls", suffix="Control")
+    def __init__(self, argv: list[str] = None) -> None:
+        """Build and parse command line."""
 
-    # Bind some controls.
-    controls.bind("HelpControl", "F1")
-    controls.bind("MotdControl", "Ctrl+F1")
-    controls.bind("DebugFlagControl", "F2")
-    controls.bind("TauntFlagControl", "F3")
-    controls.bind("ThroeFlagControl", "Shift+F3")
-    controls.bind("ShowKDControl", "F4")
-    controls.bind("ShowKillsControl", "Shift+F4")
-    controls.bind("UserPanelControl", "F5")
-    controls.bind("JoinOtherTeamControl", "F6")
-    controls.bind("SortOrderControl", "F7")
-    controls.bind("LogLocationControl", "F8")
-    controls.bind("LogLevelControl", "Shift+F8")
-    controls.bind("ResetPaddingControl", "Ctrl+F8")
-    controls.bind("GridLayoutControl", "F9")
-    controls.bind("ShowDebugControl", "KP_INS")
-    controls.bind("SingleStepControl", "KP_DEL")
-    controls.bind("KickLastCheaterControl", "[", game_only=True)
-    controls.bind("KickLastRacistControl", "]", game_only=True)
-    controls.bind("KickLastSuspectControl", "\\", game_only=True)
-    controls.bind("KicksPopControl", "KP_HOME")
-    controls.bind("KicksClearControl", "KP_LEFTARROW")
-    controls.bind("KicksPopleftControl", "KP_END")
-    controls.bind("SpamsPopControl", "KP_PGUP")
-    controls.bind("SpamsClearControl", "KP_RIGHTARROW")
-    controls.bind("SpamsPopleftControl", "KP_PGDN")
-    # controls.bind("PullControl", "KP_UPARROW")
-    controls.bind("ClearQueuesControl", "KP_5")
-    controls.bind("PushControl", "KP_DOWNARROW")
-
-    # def debug(self, text: str) -> None:
-    #     """Override to silence."""
-    # for --merge-hackers
+        threading.current_thread().name = "MAIN"
+        tf2mon.monitor = Monitor()
+        tf2mon.controls = Controls()
+        super().__init__(argv)
 
     def init_logging(self, verbose: int) -> None:
         """Set logging levels based on `--verbose`."""
@@ -129,6 +96,30 @@ class CLI(BaseCLI):
     def add_arguments(self) -> None:
         """Add arguments to parser."""
 
+        self._add_base_args()
+        tf2mon.controls.add_arguments_to(self.parser)
+        self._add_debug_args()
+        self._add_database_args()
+        self._add_fkeys_args()
+        self._add_numpad()
+        self._add_duels()
+        self._add_operate()
+        self._add_terminal()
+        self._add_windows()
+        self._add_scoreboard()
+        self._add_logfiles()
+
+    def _add_base_args(self) -> None:
+
+        arg = self.parser.add_argument(
+            "--tf2-install-dir",
+            metavar="DIR",
+            default=Path(self.config["tf2_install_dir"]),
+            type=Path,
+            help="TF2 installation directory",
+        )
+        self.add_default_to_help(arg)
+
         rewind = self.parser.add_mutually_exclusive_group()
         arg = rewind.add_argument(
             "--rewind",
@@ -165,17 +156,6 @@ class CLI(BaseCLI):
         )
         self.add_default_to_help(arg)
 
-        arg = self.parser.add_argument(
-            "--tf2-install-dir",
-            metavar="DIR",
-            default=Path(self.config["tf2_install_dir"]),
-            type=Path,
-            help="TF2 installation directory",
-        )
-        self.add_default_to_help(arg)
-
-        self.controls.add_arguments_to(self.parser)
-
         arg = self.parser.add_argument(
             "con_logfile",
             default=Path(self.config["con_logfile"]),
@@ -212,6 +192,8 @@ class CLI(BaseCLI):
         )
         self.add_default_to_help(arg)
 
+    def _add_debug_args(self) -> None:
+
         group = self.parser.add_argument_group("Debugging options")
 
         group.add_argument(
@@ -255,6 +237,8 @@ class CLI(BaseCLI):
         )
         self.add_default_to_help(arg)
 
+    def _add_database_args(self) -> None:
+
         group = self.parser.add_argument_group("Database options")
 
         arg = group.add_argument(
@@ -288,13 +272,6 @@ class CLI(BaseCLI):
             help="print hackers database and exit",
         )
 
-        # group.add_argument(
-        #     "--merge-hackers",
-        #     metavar="FILE",
-        #     type=Path,
-        #     help="merge `FILE` with `--hackers FILE` to `stdout` and exit",
-        # )
-
         self.parser.add_argument_group(
             "Configuration file",
             self.dedent(
@@ -310,6 +287,8 @@ class CLI(BaseCLI):
             ),
         )
 
+    def _add_numpad(self) -> None:
+
         self.parser.add_argument_group(
             "In-Game Controls, Numpad",
             self.dedent(
@@ -354,6 +333,8 @@ class CLI(BaseCLI):
             ),
         )
 
+    def _add_duels(self) -> None:
+
         self.parser.add_argument_group(
             "Duels",
             self.dedent(
@@ -382,12 +363,16 @@ class CLI(BaseCLI):
             ),
         )
 
+    def _add_fkeys_args(self) -> None:
+
         self.parser.add_argument_group(
             "Function Keys",
             "These function keys are available in-game and in the monitor:\n\n"
-            + self.controls.fkey_help(),
+            + tf2mon.controls.fkey_help(),
         )
 
+    def _add_operate(self) -> None:
+
         self.parser.add_argument_group(
             "Where to Operate",
             self.dedent(
@@ -411,6 +396,8 @@ class CLI(BaseCLI):
             ),
         )
 
+    def _add_terminal(self) -> None:
+
         self.parser.add_argument_group(
             "Terminal Size",
             self.dedent(
@@ -427,6 +414,7 @@ class CLI(BaseCLI):
             ),
         )
 
+    def _add_windows(self) -> None:
         self.parser.add_argument_group(
             "Resizable Windows",
             self.dedent(
@@ -440,6 +428,8 @@ class CLI(BaseCLI):
             ),
         )
 
+    def _add_scoreboard(self) -> None:
+
         self.parser.add_argument_group(
             "Scoreboard",
             self.dedent(
@@ -452,9 +442,25 @@ class CLI(BaseCLI):
             ),
         )
 
+    def _add_logfiles(self) -> None:
+        self.parser.add_argument_group(
+            "Log Files",
+            self.dedent(
+                """
+    `%(prog)s` writes plaintext messages to `fileno(2)`, and
+    colorized messages to `fileno(3)`, when open to a regular file.
+
+        $ %(prog)s 2>x 3>y
+                """
+            ),
+        )
+
     def main(self) -> None:
         """Command line interface entry point (method)."""
 
+        tf2mon.config = self.config
+        tf2mon.options = self.options
+
         if self.options.con_logfile == self.config["con_logfile"]:
             # Not given on command line; prefix with effective parent.
             # (configured default is a basename relative to `tf2_install_dir`)
@@ -487,25 +493,10 @@ class CLI(BaseCLI):
                 print(api.fetch_steamid(steamid))
             self.parser.exit()
 
-        if self.options.print_hackers:
-            Database(self.options.database)
-            hackers = HackerManager(self.options.hackers)
-            with contextlib.suppress(BrokenPipeError):
-                hackers.print_report()
-            self.parser.exit()
-
-        # if self.options.merge_hackers:
-        #     hackers = HackerManager(self.options.hackers)
-        #     hackers.load(self.options.merge_hackers)
-        #     print(str(hackers))
-        #     self.parser.exit()
-
-        tf2mon.monitor = Monitor(self)
         tf2mon.monitor.run()
 
 
-def main(args: Optional[list[str]] = None) -> None:
+def main(args: list[str] | None = None) -> None:
     """Command line interface entry point (function)."""
 
-    threading.current_thread().name = "MAIN"
     return CLI(args).main()
