@@ -77,13 +77,13 @@ class Spammer:
     def taunt(self, victim, weapon, crit):
         """Make noise when operator kills opponent."""
 
-        if tf2mon.monitor.controls["TauntFlagControl"].value:
+        if tf2mon.controls["TauntFlagControl"].value:
             self._push_spam(self._crit_taunts if crit else self._no_crit_taunts, victim, weapon)
 
     def throe(self, killer, weapon, crit):
         """Make noise when opponent kills operator."""
 
-        if tf2mon.monitor.controls["ThroeFlagControl"].value:
+        if tf2mon.controls["ThroeFlagControl"].value:
             spam = self._crit_throes if crit else self._no_crit_throes
             suffix = (" +" + killer.perk) if killer.perk else ""
             self._push_spam(spam, killer, weapon, suffix)
@@ -101,7 +101,7 @@ class Spammer:
             killed=self._killed.cycle,
             insult=self._insults.cycle,
         )
-        tf2mon.monitor.spams.push("say " + m + suffix)
+        tf2mon.controls["SpamsControl"].push("say " + m + suffix)
 
     def spam(self, spamno):
         """Respond to SPAM command."""
@@ -113,4 +113,4 @@ class Spammer:
             logger.critical(f"bad spamno {spamno!r}")
             return
 
-        tf2mon.monitor.spams.pushleft(msg)
+        tf2mon.controls["SpamsControl"].pushleft(msg)
