@@ -4,7 +4,6 @@ import contextlib
 import curses
 import os
 import sys
-import textwrap
 
 import libcurses
 from loguru import logger
@@ -66,7 +65,7 @@ class UI:
         Called at init, on KEY_RESIZE events, and when layout changes.
         """
 
-        klass = tf2mon.monitor.controls["GridLayoutControl"].value
+        klass = tf2mon.controls["GridLayoutControl"].value
         try:
             layout = klass(self.grid)
         except AssertionError:
@@ -152,10 +151,7 @@ class UI:
         self.refresh_duels(tf2mon.monitor.me)
         self.refresh_user(tf2mon.monitor.me)
         # chatwin_blu and chatwin_red are rendered from gameplay/_playerchat
-        self.scoreboard.show_scores(
-            team1=list(tf2mon.monitor.users.active_team_users(Team.BLU)),
-            team2=list(tf2mon.monitor.users.active_team_users(Team.RED)),
-        )
+        self.scoreboard.refresh()
         self.show_status()
         self.grid.refresh()
 
@@ -176,18 +172,24 @@ class UI:
         """Refresh kicks panel."""
 
         if self.kicks_win:
-            # ic(self.kicks_win.getbegyx())
-            # ic(self.kicks_win.getmaxyx())
-            self._show_lines("KICKS", reversed(tf2mon.monitor.kicks.msgs), self.kicks_win)
+            self._show_lines(
+                "KICKS",
+                reversed(tf2mon.controls["KicksControl"].msgs),
+                self.kicks_win,
+            )
 
-        # if self.user_win:
-        #     self.refresh_user(tf2mon.monitor.me)
+        if self.user_win:
+            self.refresh_user(tf2mon.monitor.me)
 
     def refresh_spams(self):
         """Refresh spams panel."""
 
         if self.spams_win:
-            self._show_lines("SPAMS", reversed(tf2mon.monitor.spams.msgs), self.spams_win)
+            self._show_lines(
+                "SPAMS",
+                reversed(tf2mon.controls["SpamsControl"].msgs),
+                self.spams_win,
+            )
 
         if self.user_win:
             self.refresh_user(tf2mon.monitor.me)
@@ -204,28 +206,26 @@ class UI:
     def refresh_user(self, user):
         """Refresh user panel."""
 
-        ctrl = tf2mon.monitor.controls["UserPanelControl"]
+        panel = tf2mon.controls["UserPanelControl"]
+        kicks = tf2mon.controls["KicksControl"]
+        spams = tf2mon.controls["SpamsControl"]
 
         if self.user_win:
-            if ctrl.value == ctrl.enum.KICKS or (
-                ctrl.value == ctrl.enum.AUTO and tf2mon.monitor.kicks.msgs
+            if panel.value == panel.enum.KICKS or (
+                panel.value == panel.enum.AUTO and kicks.msgs
             ):
                 self._show_lines(
                     "KICKS",
-                    reversed(tf2mon.monitor.kicks.msgs)
-                    if tf2mon.monitor.kicks.msgs
-                    else ["No Kicks"],
+                    reversed(kicks.msgs) if kicks.msgs else ["No Kicks"],
                     self.user_win,
                 )
             #
-            elif ctrl.value == ctrl.enum.SPAMS or (
-                ctrl.value == ctrl.enum.AUTO and tf2mon.monitor.spams.msgs
+            elif panel.value == panel.enum.SPAMS or (
+                panel.value == panel.enum.AUTO and spams.msgs
             ):
                 self._show_lines(
                     "SPAMS",
-                    reversed(tf2mon.monitor.spams.msgs)
-                    if tf2mon.monitor.spams.msgs
-                    else ["No Spams"],
+                    reversed(spams.msgs) if spams.msgs else ["No Spams"],
                     self.user_win,
                 )
             #
@@ -295,34 +295,34 @@ class UI:
         level = player.display_level
         leader = f"{level}: {player.steamid}"
 
-        # tf2mon.monitor.ui.show_journal(
+        # self.show_journal(
         #     "Player",
         #     f"{leader}: {player}",
         # )
 
-        # tf2mon.monitor.ui.show_journal(
+        # self.show_journal(
         #     level,
         #     f"{leader}: {player.astuple()}",
         # )
 
-        tf2mon.monitor.ui.show_journal(
+        self.show_journal(
             level,
             f"{leader}: name: `{player.last_name}`",
         )
 
         for alias in [x for x in player.aliases if x != player.last_name]:
-            tf2mon.monitor.ui.show_journal(
+            self.show_journal(
                 level,
                 f"{leader}: alias: `{alias}`",
             )
 
-        tf2mon.monitor.ui.show_journal(
+        self.show_journal(
             level,
             # pylint: disable=protected-access
             f"{leader}: prev={player.s_prev_time} {player._s_prev_time}",
         )
 
-        tf2mon.monitor.ui.show_journal(
+        self.show_journal(
             level,
             f"{leader}: attrs={[x for x in player.getattrs() if x]}",
         )
@@ -349,7 +349,7 @@ class UI:
     def show_status(self):
         """Update status line."""
 
-        line = tf2mon.monitor.controls.get_status_line() + f" UID={tf2mon.monitor.my.userid}"
+        line = tf2mon.controls.get_status_line() + f" UID={tf2mon.monitor.my.userid}"
 
         try:
             self.status_win.addstr(
@@ -368,42 +368,3 @@ class UI:
             for line in lines:
                 win.addstr(line + "\n", self.colormap[level])
         win.noutrefresh()
-
-    def show_help(self):
-        """Show help."""
-
-        for line in (
-            textwrap.dedent(
-                """
-    Press Enter to process next line.
-    Enter "b 500" to set breakpoint at line 500.
-    Enter "/pattern[/i]" to set search pattern.
-    Enter "/" to clear search pattern.
-    Enter "c" to continue.
-    Enter "quit" or press ^D to quit."
-                """
-            )
-            .strip()
-            .splitlines()
-        ):
-            logger.log("help", line)
-
-        for line in tf2mon.monitor.controls.fkey_help().splitlines():
-            self.show_journal("help", line)
-
-    def show_motd(self):
-        """Show message of the day."""
-
-        motd = tf2mon.monitor.tf2_scripts_dir.parent / "motd.txt"
-        logger.log("help", f" {motd} ".center(80, "-"))
-
-        with open(motd, encoding="utf-8") as file:
-            for line in file:
-                logger.log("help", line.strip())
-
-    def show_debug(self):
-        """Debug grid."""
-
-        logger.debug(self.grid)
-        for box in self.grid.boxes:
-            logger.debug(self.grid.winyx(box))
